==> huaweicloudsdkwaf-3.0.54-py2.py3-none-any.whl: huaweicloudsdkwaf/v1/model/create_geo_ip_rule_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateGeoIpRuleRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'geoip': 'str',
        'white': 'int',
        'description': 'str'
    }

    attribute_map = {
        'geoip': 'geoip',
        'white': 'white',
        'description': 'description'
    }

    def __init__(self, geoip=None, white=None, description=None):
        """CreateGeoIpRuleRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._geoip = None
        self._white = None
        self._description = None
        self.discriminator = None

        if geoip is not None:
            self.geoip = geoip
        if white is not None:
            self.white = white
        if description is not None:
            self.description = description

    @property
    def geoip(self):
        """Gets the geoip of this CreateGeoIpRuleRequestBody.

        地理位置封禁区域

        :return: The geoip of this CreateGeoIpRuleRequestBody.
        :rtype: str
        """
        return self._geoip

    @geoip.setter
    def geoip(self, geoip):
        """Sets the geoip of this CreateGeoIpRuleRequestBody.

        地理位置封禁区域

        :param geoip: The geoip of this CreateGeoIpRuleRequestBody.
        :type: str
        """
        self._geoip = geoip

    @property
    def white(self):
        """Gets the white of this CreateGeoIpRuleRequestBody.

        放行或者拦截（0拦截，1放行）

        :return: The white of this CreateGeoIpRuleRequestBody.
        :rtype: int
        """
        return self._white

    @white.setter
    def white(self, white):
        """Sets the white of this CreateGeoIpRuleRequestBody.

        放行或者拦截（0拦截，1放行）

        :param white: The white of this CreateGeoIpRuleRequestBody.
        :type: int
        """
        self._white = white

    @property
    def description(self):
        """Gets the description of this CreateGeoIpRuleRequestBody.

        创建规则时间戳

        :return: The description of this CreateGeoIpRuleRequestBody.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateGeoIpRuleRequestBody.

        创建规则时间戳

        :param description: The description of this CreateGeoIpRuleRequestBody.
        :type: str
        """
        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(sanitize_for_serialization(self))

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateGeoIpRuleRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkwaf-3.0.64-py2.py3-none-any.whl: huaweicloudsdkwaf/v1/model/create_geo_ip_rule_request_body.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class CreateGeoIpRuleRequestBody:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'geoip': 'str',
        'white': 'int',
        'description': 'str'
    }

    attribute_map = {
        'geoip': 'geoip',
        'white': 'white',
        'description': 'description'
    }

    def __init__(self, geoip=None, white=None, description=None):
        """CreateGeoIpRuleRequestBody - a model defined in huaweicloud sdk"""
        
        

        self._geoip = None
        self._white = None
        self._description = None
        self.discriminator = None

        if geoip is not None:
            self.geoip = geoip
        if white is not None:
            self.white = white
        if description is not None:
            self.description = description

    @property
    def geoip(self):
        """Gets the geoip of this CreateGeoIpRuleRequestBody.

        地理位置封禁区域

        :return: The geoip of this CreateGeoIpRuleRequestBody.
        :rtype: str
        """
        return self._geoip

    @geoip.setter
    def geoip(self, geoip):
        """Sets the geoip of this CreateGeoIpRuleRequestBody.

        地理位置封禁区域

        :param geoip: The geoip of this CreateGeoIpRuleRequestBody.
        :type: str
        """
        self._geoip = geoip

    @property
    def white(self):
        """Gets the white of this CreateGeoIpRuleRequestBody.

        放行或者拦截（0拦截，1放行）

        :return: The white of this CreateGeoIpRuleRequestBody.
        :rtype: int
        """
        return self._white

    @white.setter
    def white(self, white):
        """Sets the white of this CreateGeoIpRuleRequestBody.

        放行或者拦截（0拦截，1放行）

        :param white: The white of this CreateGeoIpRuleRequestBody.
        :type: int
        """
        self._white = white

    @property
    def description(self):
        """Gets the description of this CreateGeoIpRuleRequestBody.

        创建规则时间戳

        :return: The description of this CreateGeoIpRuleRequestBody.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateGeoIpRuleRequestBody.

        创建规则时间戳

        :param description: The description of this CreateGeoIpRuleRequestBody.
        :type: str
        """
        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateGeoIpRuleRequestBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
